Batch
=====

Simple CLi to run batches.

Installation
------------

``pip install -r requirements.txt``

Usage
-----

``./batch.py --prompts ../assets/txt/prompts/vampire/ancient.txt --negative_prompt "$(cat ../assets/txt/prompts/_negative.txt)" --batch_name vampire --output $HOME/Desktop --face ../assets/img/faces/palina.jpg``
